#!/bin/bash

# script called when an ethernet virtual interface is attached
# (action 'add') or detached (action 'remove') from a virtual 
# machine.

umask 022 

stop_dhcp_client() {
    for file_ in dhclient.$1.pid dhclient-$1.pid dhclient.pid; do
        if [ -f /var/run/$file_ ]; then
        dhpid=$(cat /var/run/$file_)
        if [ "o$dhpid" != "o" ]; then
            if (ps -eo pid,cmd | grep "$dhpid" | grep -v grep | grep -q "$1"); then
                kill "$dhpid" && rm -f "/var/run/$file_"
            fi
        fi
    fi
    done

    # for all the other cases of running dhclient on the interface
    pkill -9 -f "dhclient.*$1"
}

iface_up() {
    export PATH=$PATH:/sbin
    # fix for 3.2-xenU kernel
    IP=/bin/ip
    [ ! -x $IP ] && IP=$(which ip)
    $IP link set $1 up

    # then we can call dhclient
    [ -f /var/lib/dhclient.eth0.leases ] && rm -f /var/lib/dhclient.eth0.leases
    [ -f /var/lib/dhclient.leases ] && rm -f /var/lib/dhclient.leases
    /sbin/dhclient -1 -q $1
    stop_dhcp_client $1
}

sysctl_config() {
    if [ "$1" != 'eth0' ]; then
        # set the ARP behavior when additionnal iface are set
        sysctl -w net.ipv4.conf.$1.arp_announce=2
        sysctl -w net.ipv4.conf.$1.rp_filter=0
        sysctl -w net.ipv4.conf.$1.arp_filter=0
    fi
}

if [ -z "$INTERFACE" ]; then
        echo Interface is not defined.
        exit 1
fi

case "$ACTION" in
        "add")
                echo "Setup of $INTERFACE" | logger -t gandi
                iface_up $INTERFACE 
                sysctl_config $INTERFACE
        ;;
        "remove")
                echo "Removing of $INTERFACE" | logger -t gandi
                # nothing to do
        ;;
esac

exit 0
# vim:ft=python:et:sw=4:ts=4:sta:tw=79:fileformat=unix
